| Title: | Analyzing the Heterogeneity of Single-Cell Populations |
|---|---|
| Description: | A bioinformatics method developed for analyzing the heterogeneity of single-cell populations. Phitest provides an objective and automatic method to evaluate the performance of clustering and quality of cell clusters. |
| Authors: | Wei Vivian Li [aut, cre]
|
| Maintainer: | Wei Vivian Li <[email protected]> |
| License: | GPL-3 |
| Version: | 0.2.0 |
| Built: | 2026-05-28 10:58:43 UTC |
| Source: | https://github.com/cran/PhitestR |
Phitest for analyzing the heterogeneity of single-cell populations
phitest(object, label, ncores = 1, min.cell = 10)phitest(object, label, ncores = 1, min.cell = 10)
object |
A matrix of single-cell UMI counts (rows for genes and columns for cells). |
label |
A character or numeric vector of cluster labels. Length should be the same as
cell number and order should match the order in |
ncores |
Number of cores used for parallel computation. |
min.cell |
An integer specifying a threshold to filter genes. Genes expressed in
fewer than |
A list of two elements: pval contains the P values, and
par contains the estimated parameters.
Wei Vivian Li, [email protected]